import * as THREE from 'three';

import Stats from 'three/addons/libs/stats.module.js';
import { GUI } from 'three/addons/libs/lil-gui.module.min.js';
import { OrbitControls } from 'three/addons/controls/OrbitControls.js';


// Create a scene
const scene = new THREE.Scene();

// Create a camera
const camera = new THREE.PerspectiveCamera(75, window.innerWidth / window.innerHeight,  0.1,  1000);
        camera.position.z =  6;
        camera.position.x =  2;
        camera.position.y =  3;


// Create a renderer
const renderer = new THREE.WebGLRenderer({ alpha:true });
renderer.setSize(window.innerWidth, window.innerHeight);
document.body.appendChild(renderer.domElement);

// Create a cube
const geometry = new THREE.BoxGeometry(1,  1,  1);
const material = new THREE.MeshPhongMaterial({color:0x30c9f0, flatShading:true, shininess:100});
const cube = new THREE.Mesh(geometry, material);
cube.position.y = 3.5;
scene.add(cube);

// Gordian Knot
const KnotGeometry = new THREE.TorusKnotGeometry( 1, 0.3, 128, 32, 2, 5);
const KnotMaterial = new THREE.MeshPhongMaterial( { color: 0x60e9ff, flatShading:true, shininess:30 } );
const knot = new THREE.Mesh( KnotGeometry, KnotMaterial );
knot.position.y= 1;
scene.add(knot);

// Create Light
const color = 0xFFFFFF;
const intensity = 1;
const light = new THREE.DirectionalLight(color, intensity);
light.position.set(-1,2,4);
scene.add(light);
scene.add(new THREE.AmbientLight(0xFFFFFF, 0.4));

// Create OrbitControls
const controls = new OrbitControls( camera, renderer.domElement );
controls.target.set( 0, 1, 0 );
controls.update();

// Create GUI
const gui = new GUI();

// Add GUI controls
const cubeScale = {
            scaleX:  1,
            scaleY:  1,
            scaleZ:  1
};

const scaleFolder = gui.addFolder('Scale');
        scaleFolder.add(cubeScale, 'scaleX',  0.1,  4).onChange(() => {
            cube.scale.x = cubeScale.scaleX;
		console.log(cube.scale.x);
		fetch("../../cube/x/"+cube.scale.x);
});

scaleFolder.add(cubeScale, 'scaleY',  0.1,  4).onChange(() => {
            cube.scale.y = cubeScale.scaleY;
		console.log(cube.scale.y);
		fetch("../../cube/y/"+cube.scale.y);
        });

scaleFolder.add(cubeScale, 'scaleZ',  0.1,  4).onChange(() => {
            cube.scale.z = cubeScale.scaleZ;
		console.log(cube.scale.z);
		fetch("../../cube/z/"+cube.scale.z);
        });

scaleFolder.open();

        // Render the scene
        function animate() {
            requestAnimationFrame(animate);
            renderer.render(scene, camera);
        }
        animate();


